build_rpc_op_resolver

Function build_rpc_op_resolver 

pub fn build_rpc_op_resolver(
    ops: &'static [OpDescriptor],
) -> impl Fn(&Request<Body>) + Send + Sync
Build an op resolver for transport rpc schemas, over the generated OPS slice, for a router mounted at the root.

Returns OpAdmission::unresolved — which reserves — for a non-RPC path, for /rpc/batch, for /rpc/subscribe/..., and for any op id absent from ops.

If the router is nested, use build_rpc_op_resolver_with_prefix.